<?php

namespace Nakko\MeprMemberStatus;

class Options {
    const CACHE_DURATION = MEPR_MEMBER_STATUS_OPTION_PREFIX . "cache_duration";
    const USER_CACHE_DURATION = MEPR_MEMBER_STATUS_OPTION_PREFIX . "user_cache_duration";
    const INCLUDE_PRODUCTS = MEPR_MEMBER_STATUS_OPTION_PREFIX . "include-products";

    public static function defaults() {
        add_option(self::CACHE_DURATION, 600);
        add_option(self::USER_CACHE_DURATION, 120);
        add_option(self::INCLUDE_PRODUCTS, true);
    }

    public static function delete() {
        delete_option(self::CACHE_DURATION);
        delete_option(self::USER_CACHE_DURATION);
        delete_option(self::INCLUDE_PRODUCTS);
    }

    /**
     * Set option
     * @param string $key
     * @param $value
     * @return void
     */
    public static function set(string $key, $value) {
        update_option($key, $value);
    }

    /**
     * Get integer option
     * @param $option_name
     * @param $default_value
     * @return int|mixed|null
     */
    public static function get_int($option_name, $default_value = null) {
        $value = get_option($option_name, $default_value);
        if (isset($value) && $value) {
            return intval($value);
        }

        return $default_value;
    }

    /**
     * Get boolean option
     *
     * @param $option_name
     * @param $default_value
     * @return bool
     */
    public static function get_bool($option_name, $default_value = false) {
        return (bool)get_option($option_name, $default_value);
    }

    /**
     * @param $option_name
     * @param $default_value
     * @return string|null
     */
    public static function get_string($option_name, $default_value = null) {
        $value = get_option($option_name, $default_value);
        if (isset($value) && $value) {
            return (string)$value;
        }

        return $default_value;
    }

    /**
     * Get float option
     * @param $option_name
     * @param $default_value
     * @return float|null
     */
    public static function get_float($option_name, $default_value = null) {
        $value = get_option($option_name, $default_value);
        if (isset($value) && $value) {
            return floatval($value);
        }

        return $default_value;
    }

    /**
     * Get object option
     * @param $option_name
     * @param $default_value
     * @return object|mixed|null
     */
    public static function get_object($option_name, $default_value = null) {
        $value = get_option($option_name, $default_value);
        if (is_object($value)) {
            return $value;
        }

        return $default_value;
    }

    /**
     * Get array option
     * @param $option_name
     * @param $default_value
     * @return array|null
     */
    public static function get_array($option_name, $default_value = null) {
        $value = get_option($option_name, $default_value);
        if (is_array($value)) {
            return $value;
        }

        return $default_value;
    }
}